@@ -21,7 +21,9 @@
  * Boston, MA 02110-1301, USA.
  */
 #include <cmath>
+#include <iomanip>
 #include <iostream>
+#include <sstream>
 #include <QDebug>
 
 #include <gnuradio/prefs.h>
@@ -76,7 +78,7 @@ receiver::receiver(const std::string input_device,
 
     if (input_device.empty())
     {
-        src = osmosdr::source::make("file="+get_random_file()+",freq=428e6,rate=96000,repeat=true,throttle=true");
+        src = osmosdr::source::make("file="+escape_filename(get_zero_file())+",freq=428e6,rate=96000,repeat=true,throttle=true");
     }
     else
     {
@@ -206,7 +208,18 @@ void receiver::set_input_device(const std::string device)
         tb->disconnect(src, 0, iq_swap, 0);
     }
 
+#if GNURADIO_VERSION < 0x030802
+    //Work around GNU Radio bug #3184
+    //temporarily connect dummy source to ensure that previous device is closed
+    src = osmosdr::source::make("file="+escape_filename(get_zero_file())+",freq=428e6,rate=96000,repeat=true,throttle=true");
+    tb->connect(src, 0, iq_swap, 0);
+    tb->start();
+    tb->stop();
+    tb->wait();
+    tb->disconnect(src, 0, iq_swap, 0);
+#else
     src.reset();
+#endif
 
     try
     {
@@ -215,7 +228,7 @@ void receiver::set_input_device(const std::string device)
     catch (std::exception &x)
     {
         error = x.what();
-        src = osmosdr::source::make("file="+get_random_file()+",freq=428e6,rate=96000,repeat=true,throttle=true");
+        src = osmosdr::source::make("file="+escape_filename(get_zero_file())+",freq=428e6,rate=96000,repeat=true,throttle=true");
     }
 
     if(src->get_sample_rate() != 0)
@@ -715,9 +728,9 @@ receiver::status receiver::set_freq_corr(double ppm)
  * This method returns the current signal power detected by the receiver. The detector
  * is located after the band pass filter. The full scale is 1.0
  */
-float receiver::get_signal_pwr(bool dbfs) const
+float receiver::get_signal_pwr() const
 {
-    return rx->get_signal_level(dbfs);
+    return rx->get_signal_level();
 }
 
 /** Set new FFT size. */
@@ -845,7 +858,7 @@ receiver::status receiver::set_demod(rx_demod demod, bool force)
     if (!force && (demod == d_demod))
         return ret;
 
-    // tb->lock() seems to hang occasioanlly
+    // tb->lock() seems to hang occasionally
     if (d_running)
     {
         tb->stop();
@@ -978,7 +991,7 @@ receiver::status receiver::set_af_gain(float gain_db)
  * A new recorder object is created every time we start recording and deleted every time
  * we stop recording. The idea of creating one object and starting/stopping using different
  * file names does not work with WAV files (the initial /tmp/gqrx.wav will not be stopped
- * because the wav file can not be empty). See https://github.com/csete/gqrx/issues/36
+ * because the wav file can not be empty). See https://github.com/gqrx-sdr/gqrx/issues/36
  */
 receiver::status receiver::start_audio_recording(const std::string filename)
 {
@@ -1047,6 +1060,12 @@ receiver::status receiver::stop_audio_recording()
     wav_sink->close();
     tb->disconnect(rx, 0, wav_sink, 0);
     tb->disconnect(rx, 1, wav_sink, 1);
+
+    // Temporary workaround for https://github.com/gnuradio/gnuradio/issues/5436
+    tb->disconnect(ddc, 0, rx, 0);
+    tb->connect(ddc, 0, rx, 0);
+    // End temporary workaronud
+
     tb->unlock();
     wav_sink.reset();
     d_recording_wav = false;
@@ -1271,6 +1290,12 @@ receiver::status receiver::stop_sniffer()
 
     tb->lock();
     tb->disconnect(rx, 0, sniffer_rr, 0);
+
+    // Temporary workaround for https://github.com/gnuradio/gnuradio/issues/5436
+    tb->disconnect(ddc, 0, rx, 0);
+    tb->connect(ddc, 0, rx, 0);
+    // End temporary workaronud
+
     tb->disconnect(sniffer_rr, 0, sniffer, 0);
     tb->unlock();
     d_sniffer_active = false;
@@ -1413,3 +1438,13 @@ void receiver::reset_rds_parser(void)
 {
     rx->reset_rds_parser();
 }
+
+std::string receiver::escape_filename(std::string filename)
+{
+    std::stringstream ss1;
+    std::stringstream ss2;
+
+    ss1 << std::quoted(filename, '\'', '\\');
+    ss2 << std::quoted(ss1.str(), '\'', '\\');
+    return ss2.str();
+}
