@@ -21,6 +21,7 @@
  * Boston, MA 02110-1301, USA.
  */
 #include <math.h>
+#include <volk/volk.h>
 #include <gnuradio/io_signature.h>
 #include <gnuradio/filter/firdes.h>
 #include <gnuradio/gr_complex.h>
@@ -56,7 +57,15 @@ rx_fft_c::rx_fft_c(unsigned int fftsize, double quad_rate, int wintype)
 #endif
 
     /* allocate circular buffer */
-    d_cbuf.set_capacity(d_fftsize + d_quadrate);
+#if GNURADIO_VERSION < 0x031000
+    d_writer = gr::make_buffer(MAX_FFT_SIZE * 2, sizeof(gr_complex));
+#else
+    d_writer = gr::make_buffer(MAX_FFT_SIZE * 2, sizeof(gr_complex), 1, 1);
+#endif
+    d_reader = gr::buffer_add_reader(d_writer, 0);
+
+    memset(d_writer->write_pointer(), 0, sizeof(gr_complex) * MAX_FFT_SIZE);
+    d_writer->update_write_pointer(MAX_FFT_SIZE);
 
     /* create FFT window */
     set_window_type(wintype);
@@ -82,19 +91,22 @@ int rx_fft_c::work(int noutput_items,
                    gr_vector_const_void_star &input_items,
                    gr_vector_void_star &output_items)
 {
-    int i;
     const gr_complex *in = (const gr_complex*)input_items[0];
     (void) output_items;
 
     /* just throw new samples into the buffer */
     std::lock_guard<std::mutex> lock(d_mutex);
-    for (i = 0; i < noutput_items; i++)
-    {
-        d_cbuf.push_back(in[i]);
-    }
+
+    int items_to_copy = std::min(noutput_items, (int)d_writer->bufsize());
+    if (items_to_copy < noutput_items)
+        in += (noutput_items - items_to_copy);
+
+    if (d_writer->space_available() < items_to_copy)
+        d_reader->update_read_pointer(items_to_copy - d_writer->space_available());
+    memcpy(d_writer->write_pointer(), in, sizeof(gr_complex) * items_to_copy);
+    d_writer->update_write_pointer(items_to_copy);
 
     return noutput_items;
-
 }
 
 /*! \brief Get FFT data.
@@ -103,24 +115,20 @@ int rx_fft_c::work(int noutput_items,
  */
 void rx_fft_c::get_fft_data(std::complex<float>* fftPoints, unsigned int &fftSize)
 {
-    std::lock_guard<std::mutex> lock(d_mutex);
-
-    if (d_cbuf.size() < d_fftsize)
-    {
-        // not enough samples in the buffer
-        fftSize = 0;
-
-        return;
-    }
+    std::unique_lock<std::mutex> lock(d_mutex);
 
     std::chrono::time_point<std::chrono::steady_clock> now = std::chrono::steady_clock::now();
     std::chrono::duration<double> diff = now - d_lasttime;
+    diff = std::min(diff, std::chrono::duration<double>(d_writer->bufsize() / d_quadrate));
     d_lasttime = now;
 
     /* perform FFT */
-    d_cbuf.erase_begin(std::min((unsigned int)(diff.count() * d_quadrate * 1.001), (unsigned int)d_cbuf.size() - d_fftsize));
-    do_fft(d_fftsize);
-    //d_cbuf.clear();
+    d_reader->update_read_pointer(std::min((int)(diff.count() * d_quadrate * 1.001), d_reader->items_available() - MAX_FFT_SIZE));
+    apply_window(d_fftsize);
+    lock.unlock();
+
+    /* compute FFT */
+    d_fft->execute();
 
     /* get FFT data */
     memcpy(fftPoints, d_fft->get_outbuf(), sizeof(gr_complex)*d_fftsize);
@@ -134,33 +142,25 @@ void rx_fft_c::get_fft_data(std::complex<float>* fftPoints, unsigned int &fftSiz
  * Note that this function does not lock the mutex since the caller, get_fft_data()
  * has already locked it.
  */
-void rx_fft_c::do_fft(unsigned int size)
+void rx_fft_c::apply_window(unsigned int size)
 {
     /* apply window, if any */
+    gr_complex * p = (gr_complex *)d_reader->read_pointer();
+    p += (MAX_FFT_SIZE - d_fftsize);
     if (d_window.size())
     {
         gr_complex *dst = d_fft->get_inbuf();
-        for (unsigned int i = 0; i < size; i++)
-            dst[i] = d_cbuf[i] * d_window[i];
+        volk_32fc_32f_multiply_32fc(dst, p, &d_window[0], size);
     }
     else
     {
-        memcpy(d_fft->get_inbuf(), d_cbuf.linearize(), sizeof(gr_complex)*size);
+        memcpy(d_fft->get_inbuf(), p, sizeof(gr_complex)*size);
     }
-
-    /* compute FFT */
-    d_fft->execute();
 }
 
 /*! \brief Update circular buffer and FFT object. */
 void rx_fft_c::set_params()
 {
-    std::lock_guard<std::mutex> lock(d_mutex);
-
-    /* clear and resize circular buffer */
-    d_cbuf.clear();
-    d_cbuf.set_capacity(d_fftsize + d_quadrate);
-
     /* reset window */
     int wintype = d_wintype; // FIXME: would be nicer with a window_reset()
     d_wintype = -1;
@@ -257,10 +257,20 @@ rx_fft_f::rx_fft_f(unsigned int fftsize, double audio_rate, int wintype)
 #endif
 
     /* allocate circular buffer */
-    d_cbuf.set_capacity(d_fftsize + d_audiorate);
+#if GNURADIO_VERSION < 0x031000
+    d_writer = gr::make_buffer(AUDIO_BUFFER_SIZE, sizeof(float));
+#else
+    d_writer = gr::make_buffer(AUDIO_BUFFER_SIZE, sizeof(float), 1, 1);
+#endif
+    d_reader = gr::buffer_add_reader(d_writer, 0);
+
+    memset(d_writer->write_pointer(), 0, sizeof(gr_complex) * d_fftsize);
+    d_writer->update_write_pointer(d_fftsize);
 
     /* create FFT window */
     set_window_type(wintype);
+
+    d_lasttime = std::chrono::steady_clock::now();
 }
 
 rx_fft_f::~rx_fft_f()
@@ -281,16 +291,20 @@ int rx_fft_f::work(int noutput_items,
                    gr_vector_const_void_star &input_items,
                    gr_vector_void_star &output_items)
 {
-    int i;
     const float *in = (const float*)input_items[0];
     (void) output_items;
 
     /* just throw new samples into the buffer */
     std::lock_guard<std::mutex> lock(d_mutex);
-    for (i = 0; i < noutput_items; i++)
-    {
-        d_cbuf.push_back(in[i]);
-    }
+
+    int items_to_copy = std::min(noutput_items, (int)d_writer->bufsize());
+    if (items_to_copy < noutput_items)
+        in += (noutput_items - items_to_copy);
+
+    if (d_writer->space_available() < items_to_copy)
+        d_reader->update_read_pointer(items_to_copy - d_writer->space_available());
+    memcpy(d_writer->write_pointer(), in, sizeof(float) * items_to_copy);
+    d_writer->update_write_pointer(items_to_copy);
 
     return noutput_items;
 }
@@ -301,24 +315,20 @@ int rx_fft_f::work(int noutput_items,
  */
 void rx_fft_f::get_fft_data(std::complex<float>* fftPoints, unsigned int &fftSize)
 {
-    std::lock_guard<std::mutex> lock(d_mutex);
-
-    if (d_cbuf.size() < d_fftsize)
-    {
-        // not enough samples in the buffer
-        fftSize = 0;
-
-        return;
-    }
+    std::unique_lock<std::mutex> lock(d_mutex);
 
     std::chrono::time_point<std::chrono::steady_clock> now = std::chrono::steady_clock::now();
     std::chrono::duration<double> diff = now - d_lasttime;
+    diff = std::min(diff, std::chrono::duration<double>(d_writer->bufsize() / d_audiorate));
     d_lasttime = now;
 
     /* perform FFT */
-    d_cbuf.erase_begin(std::min((unsigned int)(diff.count() * d_audiorate * 1.001), (unsigned int)d_cbuf.size() - d_fftsize));
-    do_fft(d_fftsize);
-    //d_cbuf.clear();
+    d_reader->update_read_pointer(std::min((unsigned int)(diff.count() * d_audiorate * 1.001), d_reader->items_available() - d_fftsize));
+    apply_window(d_fftsize);
+    lock.unlock();
+
+    /* compute FFT */
+    d_fft->execute();
 
     /* get FFT data */
     memcpy(fftPoints, d_fft->get_outbuf(), sizeof(gr_complex)*d_fftsize);
@@ -332,25 +342,21 @@ void rx_fft_f::get_fft_data(std::complex<float>* fftPoints, unsigned int &fftSiz
  * Note that this function does not lock the mutex since the caller, get_fft_data()
  * has already locked it.
  */
-void rx_fft_f::do_fft(unsigned int size)
+void rx_fft_f::apply_window(unsigned int size)
 {
     gr_complex *dst = d_fft->get_inbuf();
-    unsigned int i;
-
+    float * p = (float *)d_reader->read_pointer();
     /* apply window, and convert to complex */
     if (d_window.size())
     {
-        for (i = 0; i < size; i++)
-            dst[i] = d_cbuf[i] * d_window[i];
+        for (unsigned int i = 0; i < size; i++)
+            dst[i] = p[i] * d_window[i];
     }
     else
     {
-        for (i = 0; i < size; i++)
-            dst[i] = d_cbuf[i];
+        for (unsigned int i = 0; i < size; i++)
+            dst[i] = p[i];
     }
-
-    /* compute FFT */
-    d_fft->execute();
 }
 
 
@@ -359,14 +365,8 @@ void rx_fft_f::set_fft_size(unsigned int fftsize)
 {
     if (fftsize != d_fftsize)
     {
-        std::lock_guard<std::mutex> lock(d_mutex);
-
         d_fftsize = fftsize;
 
-        /* clear and resize circular buffer */
-        d_cbuf.clear();
-        d_cbuf.set_capacity(d_fftsize);
-
         /* reset window */
         int wintype = d_wintype; // FIXME: would be nicer with a window_reset()
         d_wintype = -1;
