@@ -228,10 +228,7 @@ void CPlotter::mouseMoveEvent(QMouseEvent* event)
                     setCursor(QCursor(Qt::SizeHorCursor));
                 m_CursorCaptured = CENTER;
                 if (m_TooltipsEnabled)
-                    QToolTip::showText(event->globalPos(),
-                                       QString("Demod: %1 kHz")
-                                               .arg(m_DemodCenterFreq/1.e3, 0, 'f', 3),
-                                       this);
+                    showToolTip(event, QString("Demod: %1 kHz").arg(m_DemodCenterFreq/1.e3, 0, 'f', 3));
             }
             else if (isPointCloseTo(pt.x(), m_DemodHiCutFreqX, m_CursorCaptureDelta))
             {
@@ -240,10 +237,7 @@ void CPlotter::mouseMoveEvent(QMouseEvent* event)
                     setCursor(QCursor(Qt::SizeFDiagCursor));
                 m_CursorCaptured = RIGHT;
                 if (m_TooltipsEnabled)
-                    QToolTip::showText(event->globalPos(),
-                                       QString("High cut: %1 Hz")
-                                               .arg(m_DemodHiCutFreq),
-                                       this);
+                    showToolTip(event, QString("High cut: %1 Hz").arg(m_DemodHiCutFreq));
             }
             else if (isPointCloseTo(pt.x(), m_DemodLowCutFreqX, m_CursorCaptureDelta))
             {
@@ -252,10 +246,7 @@ void CPlotter::mouseMoveEvent(QMouseEvent* event)
                     setCursor(QCursor(Qt::SizeBDiagCursor));
                 m_CursorCaptured = LEFT;
                 if (m_TooltipsEnabled)
-                    QToolTip::showText(event->globalPos(),
-                                       QString("Low cut: %1 Hz")
-                                               .arg(m_DemodLowCutFreq),
-                                       this);
+                    showToolTip(event, QString("Low cut: %1 Hz").arg(m_DemodLowCutFreq));
             }
             else
             {	//if not near any grab boundaries
@@ -277,7 +268,7 @@ void CPlotter::mouseMoveEvent(QMouseEvent* event)
                         for (auto & hoverBand : hoverBands)
                             toolTipText.append("\n" + hoverBand.name);
                     }
-                    QToolTip::showText(event->globalPos(), toolTipText, this);
+                    showToolTip(event, toolTipText);
                 }
             }
             m_GrabPosition = 0;
@@ -299,11 +290,9 @@ void CPlotter::mouseMoveEvent(QMouseEvent* event)
             QDateTime tt;
             tt.setMSecsSinceEpoch(msecFromY(pt.y()));
 
-            QToolTip::showText(event->globalPos(),
-                               QString("%1\n%2 kHz")
+            showToolTip(event, QString("%1\n%2 kHz")
                                        .arg(tt.toString("yyyy.MM.dd hh:mm:ss.zzz"))
-                                       .arg(freqFromX(pt.x())/1.e3, 0, 'f', 3),
-                               this);
+                                       .arg(freqFromX(pt.x())/1.e3, 0, 'f', 3));
         }
     }
     // process mouse moves while in cursor capture modes
@@ -340,7 +329,7 @@ void CPlotter::mouseMoveEvent(QMouseEvent* event)
     }
     else if (XAXIS == m_CursorCaptured)
     {
-        if (event->buttons() & (Qt::LeftButton | Qt::MidButton))
+        if (event->buttons() & (Qt::LeftButton | Qt::MiddleButton))
         {
             setCursor(QCursor(Qt::ClosedHandCursor));
             // pan viewable range or move center frequency
@@ -348,7 +337,7 @@ void CPlotter::mouseMoveEvent(QMouseEvent* event)
             qint64 delta_hz = delta_px * m_Span / (m_OverlayPixmap.width() / m_DPR);
             if (delta_hz != 0) // update m_Xzero only on real change
             {
-                if (event->buttons() & Qt::MidButton)
+                if (event->buttons() & Qt::MiddleButton)
                 {
                     m_CenterFreq += delta_hz;
                     m_DemodCenterFreq += delta_hz;
@@ -651,7 +640,7 @@ void CPlotter::mousePressEvent(QMouseEvent * event)
                 m_GrabPosition = 1;
                 drawOverlay();
             }
-            else if (event->buttons() == Qt::MidButton)
+            else if (event->buttons() == Qt::MiddleButton)
             {
                 // set center freq
                 m_CenterFreq = roundFreq(freqFromX(pt.x()), m_ClickResolution);
@@ -790,7 +779,11 @@ void CPlotter::zoomOnXAxis(float level)
 // Called when a mouse wheel is turned
 void CPlotter::wheelEvent(QWheelEvent * event)
 {
-    QPoint pt = event->pos();
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+    QPointF pt = QPointF(event->pos());
+#else
+    QPointF pt = event->position();
+#endif
     int delta = m_InvertScrolling? -event->angleDelta().y() : event->angleDelta().y();
     int numDegrees = delta / 8;
     int numSteps = numDegrees / 15;  /** FIXME: Only used for direction **/
@@ -1353,7 +1346,7 @@ void CPlotter::drawOverlay()
             const auto levelNHeightBottom = levelNHeight + fontHeight;
             const auto levelNHeightBottomSlant = levelNHeightBottom + slant;
 
-            m_Taglist.append(qMakePair<QRect, qint64>(QRect(x, levelNHeight, nameWidth + slant, fontHeight), tag.frequency));
+            m_Taglist.append(qMakePair(QRect(x, levelNHeight, nameWidth + slant, fontHeight), tag.frequency));
 
             QColor color = QColor(tag.GetColor());
             color.setAlpha(0x60);
@@ -1770,6 +1763,15 @@ void CPlotter::calcDivSize (qint64 low, qint64 high, int divswanted, qint64 &adj
     qCDebug(plotter) << "divs:" << divs;
 }
 
+void CPlotter::showToolTip(QMouseEvent* event, QString toolTipText)
+{
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QToolTip::showText(event->globalPos(), toolTipText, this);
+#else
+    QToolTip::showText(event->globalPosition().toPoint(), toolTipText, this);
+#endif
+}
+
 // contributed by Chris Kuethe @ckuethe
 // source https://ai.googleblog.com/2019/08/turbo-improved-rainbow-colormap-for.html
 unsigned char turbo[256][3] = {
